@@ -22,6 +22,7 @@ sys.path.insert(0, os.path.abspath('../..'))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.intersphinx',
     'oslosphinx',
     'oslo_config.sphinxext',
 ]
@@ -74,5 +75,8 @@ latex_documents = [
      u'OpenStack Foundation', 'manual'),
 ]
 
-# Example configuration for intersphinx: refer to the Python standard library.
-# intersphinx_mapping = {'http://docs.python.org/': None}
+intersphinx_mapping = {
+    'python': ('https://docs.python.org/', None),
+    'osloconfig': ('http://docs.openstack.org/developer/oslo.config/', None),
+    'dogpilecache': ('https://dogpilecache.readthedocs.io/en/latest/', None),
+}
