@@ -29,22 +29,20 @@ FILE_OPTIONS = {
                         'the dogpile.cache region. This applies to any '
                         'cached method that doesn\'t have an explicit '
                         'cache expiration time defined for it.'),
-        # NOTE(morganfainberg): the dogpile.cache.memory acceptable in devstack
-        # and other such single-process/thread deployments. Running
-        # dogpile.cache.memory in any other configuration has the same pitfalls
-        # as the KVS token backend. It is recommended that either Redis or
+        # NOTE(morganfainberg): It is recommended that either Redis or
         # Memcached are used as the dogpile backend for real workloads. To
         # prevent issues with the memory cache ending up in "production"
-        # unintentionally, we register a no-op as the keystone default caching
-        # backend.
+        # unintentionally, we register a no-op as the default caching backend.
         cfg.StrOpt('backend', default=_DEFAULT_BACKEND,
                    help='Dogpile.cache backend module. It is recommended '
-                        'that Memcache with pooling '
-                        '(oslo_cache.memcache_pool) or Redis '
-                        '(dogpile.cache.redis) be used in production '
-                        'deployments.  Small workloads (single process) '
-                        'like devstack can use the dogpile.cache.memory '
-                        'backend.'),
+                        'that Memcache or Redis (dogpile.cache.redis) be used '
+                        'in production deployments. For eventlet-based or '
+                        'highly threaded servers, Memcache with pooling '
+                        '(oslo_cache.memcache_pool) is recommended. For low '
+                        'thread servers, dogpile.cache.memcached is '
+                        'recommended. Test environments with a single '
+                        'instance of the server can use the '
+                        'dogpile.cache.memory backend.'),
         cfg.MultiStrOpt('backend_argument', default=[], secret=True,
                         help='Arguments supplied to the backend module. '
                              'Specify this option once per argument to be '
